@@ -33,7 +33,7 @@ from http.client import HTTPConnection
 import datetime
 import json
 import urllib.parse
-import time
+import re
 
 
 class ApiRequest:
@@ -85,8 +85,8 @@ class ApiRequest:
                 requests.  Defaults to None.
             base_url_override (bool): The default setting of self.base_url set
                 on initialization can be overwritten using this argument.
-            verify(bool): Mandatory SSL verification is turned on by default and
-                can be turned off using this method.
+            verify(bool): Mandatory SSL verification is turned on by default
+                and can be turned off using this method.
 
         Returns:
             string or None: Usually a JSON string containing
@@ -343,8 +343,8 @@ class Matrix(ApiRequest):
             string: The Matrix server's homeserver name or FQDN, usually
             something like matrix.DOMAIN or DOMAIN
         """
-        resp = self.query("get", "key/v2/server",
-            base_url_override=server_server_uri
+        resp = self.query(
+            "get", "key/v2/server", base_url_override=server_server_uri
         )
         if not resp or not resp.get("server_name"):
             self.log.error("The homeserver name could not be fetched via the "
@@ -416,8 +416,8 @@ class SynapseAdmin(ApiRequest):
             user_id (string): Fully qualified Matrix user ID
             room_aliases (bool): Return human readable room aliases instead of
                 room ID's if applicable.
-            matrix_api (object): An initialized Matrix object needs to be passes
-                as we need some Matrix API functionality here.
+            matrix_api (object): An initialized Matrix object needs to be
+                passes as we need some Matrix API functionality here.
 
         Returns:
             string: JSON string containing the admin API's response or None if
@@ -625,8 +625,8 @@ class SynapseAdmin(ApiRequest):
                 break
             if device_id:
                 if device.get("device_id", None) == device_id:
-                    # Found device in question. Make last_seen_ts human readable
-                    # (if requested) and add to deletion list.
+                    # Found device in question. Make last_seen_ts human
+                    # readable (if requested) and add to deletion list.
                     if readable_seen:
                         device["last_seen_ts"] = self._datetime_from_timestamp(
                             device.get("last_seen_ts", None), as_str=True)
@@ -636,7 +636,7 @@ class SynapseAdmin(ApiRequest):
                     # Continue looking for the device in question.
                     continue
             if min_days:
-                seen = device.get("last_seen_ts", None)  # Get timestamp or None
+                seen = device.get("last_seen_ts", None)  # Get ts or None
                 # A device with "null" as last seen was either seen a very long
                 # time ago _or_ was created through the matrix API (e.g. via
                 # `synadm matrix login`).
@@ -663,6 +663,19 @@ class SynapseAdmin(ApiRequest):
         return self.query("post", f"v2/users/{user_id}/delete_devices",
                           data={"devices": devices})
 
+    def user_auth_provider_search(self, provider, external_id):
+        """ Finds a user based on their ID (external id) in auth provider
+        represented by auth provider id (provider).
+        """
+        return self.query("get",
+                          f"v1/auth_providers/{provider}/users/{external_id}")
+
+    def user_3pid_search(self, medium, address):
+        """ Finds a user based on their Third Party ID by specifying what kind
+        of 3PID it is as medium.
+        """
+        return self.query("get", f"v1/threepid/{medium}/users/{address}")
+
     def room_join(self, room_id_or_alias, user_id):
         """ Allow an administrator to join an user account with a given user_id
         to a room with a given room_id_or_alias
@@ -704,7 +717,8 @@ class SynapseAdmin(ApiRequest):
         return self.query("get", f"v1/rooms/{room_id}/state")
 
     def room_power_levels(self, from_, limit, name, order_by, reverse,
-                          room_id=None, all_details=True, output_format="json"):
+                          room_id=None, all_details=True,
+                          output_format="json"):
         """ Get a list of configured power_levels in all rooms.
 
         or a single room.
@@ -717,8 +731,8 @@ class SynapseAdmin(ApiRequest):
                 an exception occured. See Synapse admin API docs for details.
         """
         if room_id:
-            # We use the "name search" possibility of the room list API to get a
-            # single room via it's ID.
+            # We use the "name search" possibility of the room list API to get
+            # a single room via it's ID.
             rooms = self.room_list(from_, limit, room_id, order_by, reverse)
         else:
             rooms = self.room_list(from_, limit, name, order_by, reverse)
@@ -731,7 +745,7 @@ class SynapseAdmin(ApiRequest):
                 if s["type"] == "m.room.power_levels":
                     if output_format == "human":
                         levels_list = [
-                            f"{u} {l}" for u, l in s["content"]["users"].items()
+                            f"{u} {l}" for u, l in s["content"]["users"].items()  # noqa: E501
                         ]
                         rooms["rooms"][i][
                             "power_levels"
@@ -747,7 +761,7 @@ class SynapseAdmin(ApiRequest):
                                  "join_rules", "joined_local_members",
                                  "joined_members", "public", "state_events",
                                  "version"]:
-                    del(rooms["rooms"][i][del_item])
+                    del (rooms["rooms"][i][del_item])
 
         rooms["rooms_w_power_levels_curr_batch"] = rooms_w_power_count
         return rooms
@@ -1139,3 +1153,59 @@ class SynapseAdmin(ApiRequest):
         else:
             method = "post"
         return self.query(method, f"v1/users/{user_id}/shadow_ban")
+
+    def notice_send(self, receivers, content_plain, content_html, paginate,
+                    regex):
+        """ Send server notices.
+
+        Args:
+            receivers (string): Target(s) of the notice. Either localpart or
+                regular expression matching localparts.
+            content_plain (string): Unformatted text of the notice.
+            content_html (string): HTML-formatted text of the notice.
+            paginate (int): Limits to how many users the notice is sent at
+                once.  Users are fetched with the user_list method and using
+                its pagination capabilities.
+            to_regex (bool): Selects whether receivers should be interpreted as
+                a regular expression or a single recipient.
+
+        Returns:
+            list: A list of dictionaries, each containing the response of
+                what a single notice admin API call returned. Usually that is
+                an event ID or an error. See Synapse admin API docs for
+                details.
+        """
+        data = {
+            "user_id": "",
+            "content": {
+                "msgtype": "m.text",
+                "body": content_plain,
+                "format": "org.matrix.custom.html",
+                "formatted_body": content_html
+            }
+        }
+
+        # A regular expression was supplied to match receivers.
+        if regex:
+            outputs = []
+            response = self.user_list(0, paginate, True, False, "", "")
+            if "users" not in response:
+                return
+            while True:
+                for user in response["users"]:
+                    if re.match(receivers, user["name"]):
+                        data["user_id"] = user["name"]
+                        outputs.append(
+                            self.query(
+                                "post", "v1/send_server_notice", data=data
+                            )
+                        )
+
+                if "next_token" not in response:
+                    return outputs
+                response = self.user_list(response["next_token"],
+                                          100, True, False, "", "")
+        # Only a single user ID was supplied as receiver
+        else:
+            data["user_id"] = receivers
+            return [self.query("post", "v1/send_server_notice", data=data)]
