@@ -190,9 +190,9 @@ class APIHelper:
         When homeserver is set in the config already, it's just returned and
         nothing is tried to be fetched automatically. If not, either the
         location of the Federation API is looked up via a .well-known resource
-        or a DNS SRV lookup. This depends on the server_discovery setting in the
-        config. Finally the Federation API is used to retrieve the homeserver
-        name.
+        or a DNS SRV lookup. This depends on the server_discovery setting in
+        the config. Finally the Federation API is used to retrieve the
+        homeserver name.
 
         Args:
             uri (string): proto://name:port or proto://fqdn:port
@@ -203,7 +203,7 @@ class APIHelper:
         uri = uri if uri else self.config["base_url"]
         echo = self.log.info if self.batch else click.echo
         if self.config["homeserver"] != "auto-retrieval":
-            return  self.config["homeserver"]
+            return self.config["homeserver"]
 
         if self.config["server_discovery"] == "well-known":
             if "localhost" in self.config["base_url"]:
@@ -217,7 +217,9 @@ class APIHelper:
                 echo(
                     "Trying to fetch federation URI via well-known resource..."
                 )
-                federation_uri = self.misc_request.federation_uri_well_known(uri)
+                federation_uri = self.misc_request.federation_uri_well_known(
+                    uri
+                )
                 if not federation_uri:
                     return None
             return self.matrix_api.server_name_keys_api(federation_uri)
@@ -256,17 +258,24 @@ class APIHelper:
 
         Returns:
             string: the fully qualified Matrix User ID (MXID) or None if the
-                user_id parameter is None.
+                user_id parameter is None or no regex matched.
         """
         if user_id is None:
+            self.log.debug("Missing input in generate_mxid().")
             return None
-        elif re.match(r"@[-./=\w]+:[-.\w]+", user_id):
+        elif re.match(r"^@[-./=\w]+:[-\[\].:\w]+$", user_id):
+            self.log.debug("A proper MXID was passed.")
             return user_id
-        else:
+        elif re.match(r"^@?[-./=\w]+:?$", user_id):
+            self.log.debug("A proper localpart was passed, generating MXID "
+                           "for local homeserver.")
             localpart = re.sub("[@:]", "", user_id)
             mxid = "@{}:{}".format(localpart, self.retrieve_homeserver_name())
             return mxid
-
+        else:
+            self.log.error("Neither an MXID nor a proper localpart was "
+                           "passed.")
+            return None
 
 
 @click.group(
@@ -276,8 +285,15 @@ class APIHelper:
     "--verbose", "-v", count=True, default=False,
     help="Enable INFO (-v) or DEBUG (-vv) logging on console.")
 @click.option(
-    "--batch/--no-batch", default=False,
-    help="Enable batch behavior (no interactive prompts).")
+    "--batch", "--yes", "--non-interactive", "--scripting",
+    default=False, is_flag=True,
+    help="""Enable batch processing mode. Use with caution! This will:
+
+    \b
+        - Disable all interactive prompts.
+        - Disable automatic translation of unix timestamps to human readable
+          formats.
+    """)
 @click.option(
     "--output", "-o", default="",
     type=click.Choice(["yaml", "json", "human", "pprint",
@@ -304,7 +320,7 @@ def root(ctx, verbose, batch, output, config_file):
 
 @root.command(name="config")
 @click.option(
-    "--user", "-u", type=str,
+    "--user", "-u", "user_", type=str,
     help="Admin user allowed to access the Synapse admin API's.")
 @click.option(
     "--token", "-t", type=str,
@@ -329,13 +345,13 @@ def root(ctx, verbose, batch, output, config_file):
     API's or Matrix API's. The default is 7 seconds. """)
 @click.option(
     "--output", "-o", type=click.Choice(["yaml", "json", "human", "pprint"]),
-    help="""How synadm displays data by default. 'human' gives a tabular or list
-    view depending on the fetched data. This mode needs your terminal to be
-    quite wide! 'json' displays exactly as the API responded. 'pprint' shows
-    nicely formatted json. 'yaml' is the currently recommended output format. It
-    doesn't need as much terminal width as 'human' does. Note that the default
-    output format can always be overridden by using global switch -o (eg 'synadm
-    -o pprint user list').""")
+    help="""How synadm displays data by default. 'human' gives a tabular or
+    list view depending on the fetched data. This mode needs your terminal to
+    be quite wide! 'json' displays exactly as the API responded. 'pprint' shows
+    nicely formatted json. 'yaml' is the currently recommended output format.
+    It doesn't need as much terminal width as 'human' does. Note that the
+    default output format can always be overridden by using global switch -o
+    (eg 'synadm -o pprint user list').""")
 @click.option(
     "--server-discovery", "-d", type=click.Choice(["well-known", "dns"]),
     help="""The method used for discovery of "the own homeserver name". Since
@@ -361,7 +377,7 @@ def root(ctx, verbose, batch, output, config_file):
     method set by --server-discovery."""
 )
 @click.pass_obj
-def config_cmd(helper, user, token, base_url, admin_path, matrix_path,
+def config_cmd(helper, user_, token, base_url, admin_path, matrix_path,
                output, timeout, server_discovery, homeserver):
     """ Modify synadm's configuration. Configuration details are generally
     always asked interactively. Command line options override the suggested
@@ -387,7 +403,7 @@ def config_cmd(helper, user, token, base_url, admin_path, matrix_path,
         else:
             click.echo("Saving to config file.")
             if helper.write_config({
-                "user": user,
+                "user": user_,
                 "token": token,
                 "base_url": base_url,
                 "admin_path": admin_path,
@@ -405,7 +421,7 @@ def config_cmd(helper, user, token, base_url, admin_path, matrix_path,
     helper.write_config({
         "user": click.prompt(
             "Synapse admin user name",
-            default=user if user else helper.config.get("user", user)),
+            default=user_ if user_ else helper.config.get("user", user_)),
         "token": click.prompt(
             get_redacted_token_prompt(token),
             default=token if token else helper.config.get("token", token),
@@ -436,7 +452,7 @@ def config_cmd(helper, user, token, base_url, admin_path, matrix_path,
                 "homeserver", homeserver)),
         "server_discovery": click.prompt(
             "Server discovery mode (used with homeserver name auto-retrieval)",
-            default=server_discovery if server_discovery else helper.config.get(
+            default=server_discovery if server_discovery else helper.config.get(  # noqa: E501
                 "server_discovery", server_discovery),
             type=click.Choice(["well-known", "dns"])),
     })
@@ -458,4 +474,4 @@ def version(helper):
 
 
 # Import additional commands
-from synadm.cli import room, user, media, group, history, matrix, regtok
+from synadm.cli import room, user, media, group, history, matrix, regtok, notice  # noqa: F401, E402, E501
