@@ -142,8 +142,8 @@ def deactivate(ctx, helper, user_id, gdpr_erase):
 @click.argument("user_id", type=str)
 @click.option(
     "--list-only", "-l", is_flag=True, default=False,
-    help="""Dry-run: does not perform the deletion but shows what would be done.
-    If you want to list all devices/sessions, you can also use the whois
+    help="""Dry-run: does not perform the deletion but shows what would be
+    done. If you want to list all devices/sessions, you can also use the whois
     command.""",
     show_default=True)
 @click.option(
@@ -153,8 +153,8 @@ def deactivate(ctx, helper, user_id, gdpr_erase):
     show_default=True)
 @click.option(
     "--min-surviving", "-s", type=int, default=1,
-    help="""Stop processing devices when only this number of devices is left for
-    this user. Allows to reduce disruption by preserving recently used
+    help="""Stop processing devices when only this number of devices is left
+    for this user. Allows to reduce disruption by preserving recently used
     devices/sessions.""",
     show_default=True)
 @click.option(
@@ -172,16 +172,16 @@ def prune_devices_cmd(helper, user_id, list_only, min_days, min_surviving,
     """ Delete devices and invalidate access tokens of a user.
 
     Deletes devices of a user and invalidates any access token associated with
-    them. Starts from deleting the oldest devices, not seen in a number of days,
-    which may be abandoned.
+    them. Starts from deleting the oldest devices, not seen in a number of
+    days, which may be abandoned.
 
-    Note that this will affect the encryption and decryption of messages sent by
-    other users to this user or to rooms where the user is present.
+    Note that this will affect the encryption and decryption of messages sent
+    by other users to this user or to rooms where the user is present.
     """
     mxid = helper.generate_mxid(user_id)
     devices_data = helper.api.user_devices(mxid)
     if "devices" not in devices_data:
-        # Most probably the requested user is not existing, show error and quit.
+        # Most probably the requested user is not existing, error out and quit.
         helper.output(devices_data)
         raise SystemExit(1)
 
@@ -248,7 +248,8 @@ def password_cmd(helper, user_id, password, no_logout):
 @click.argument("user_id", type=str)
 @click.option(
     "--aliases/--ids", is_flag=True, default=True,
-    help="Display rooms as canonical aliases or room ID's.  [default: aliases]")
+    help="""Display rooms as canonical aliases or room
+    ID's.  [default: aliases]""")
 @click.pass_obj
 def membership(helper, user_id, aliases):
     """ List all rooms a user is member of.
@@ -284,8 +285,8 @@ def membership(helper, user_id, aliases):
 def user_search_cmd(ctx, search_term, from_, limit):
     """ A shortcut to \'synadm user list -d -g -n <search-term>\'.
 
-    Searches for users by name/matrix-ID, including deactivated users as well as
-    guest users. Also, compared to the original command, a case-insensitive
+    Searches for users by name/matrix-ID, including deactivated users as well
+    as guest users. Also, compared to the original command, a case-insensitive
     search is done.
     """
     click.echo("User search results for '{}':".format(search_term.lower()))
@@ -430,7 +431,7 @@ def modify(ctx, helper, user_id, password, password_prompt, display_name,
 @click.argument("user_id", type=str)
 @click.pass_obj
 def whois(helper, user_id):
-    """ Return information about the active sessions for a specific user
+    """ View information about a user's active session.
     """
     mxid = helper.generate_mxid(user_id)
     user_data = helper.api.user_whois(mxid)
@@ -532,9 +533,9 @@ def user_login_cmd(helper, user_id, expire_days, expire, expire_ts,
     day (24h) is used. If it's desired that the token never expires, use
     --expire-never
 
-    This API does not generate a new device for the user, and so will not appear
-    in their /devices list, and in general the target user should not be able to
-    tell they have been logged in as.
+    This API does not generate a new device for the user, and so will not
+    appear in their /devices list, and in general the target user should not be
+    able to tell they have been logged in as.
 
     To expire the token before the expiry date/time is reached, call the
     standard /logout API with the token. Note: The token will expire if the
@@ -555,16 +556,17 @@ def user_login_cmd(helper, user_id, expire_days, expire, expire_ts,
             raise SystemExit(1)
         helper.output(user_login)
     else:
-        click.echo("You are fetching an authentication token of a user, which "
-                   "enables you to execute any Matrix command on their behalf. "
-                   "Please respect their privacy and know what you are doing! "
-                   "Be responsible!\n")
+        click.echo("""You are fetching an authentication token of a user,
+                   which enables you to execute any Matrix command on their
+                   behalf. Please respect their privacy and know what you are
+                   doing! Be responsible!\n""")
         if user_login is None:
             click.echo(f"Login as user {user_id} not successful.")
             raise SystemExit(1)
         else:
             helper.output(user_login)
 
+
 @user.command(name="shadow-ban")
 @click.argument("user_id", type=str)
 @click.option(
@@ -599,3 +601,42 @@ def user_shadow_ban(helper, user_id, unban):
             click.echo("Successfully {}ned user: {}".format(action, user_id))
     else:
         helper.output(user_ban)
+
+
+@user.command(name="auth-provider")
+@click.argument("external_user_id", type=str)
+@click.option(
+    "-p", "--provider", is_flag=False, required=True, default=None,
+    show_default=True, help="""Provider ID as advertised in supported
+    authenticated methods in `m.login.sso` api response such as 'oidc' or
+    'google' or 'github'"""
+)
+@click.pass_obj
+def auth_provider_search(helper, provider, external_user_id):
+    """Find a user based on their ID in auth-provider.
+
+    Finds a user based on their external user ID in a particular auth provider
+    where provider is the auth provider ID as advertised in supported
+    authenticated methods in `m.login.sso` api response such as 'oidc' or
+    'google' or 'github'.
+    """
+    helper.output(
+        helper.api.user_auth_provider_search(provider, external_user_id)
+    )
+
+
+@user.command(name="3pid")
+@click.argument("address", type=str)
+@click.option(
+    "-m", "--medium", is_flag=False, required=True, default="email",
+    show_default=True, help="""Medium specifies what kind of Third Party ID is
+    used such as 'email' or 'msidn'"""
+)
+@click.pass_obj
+def third_party_id_search(helper, medium, address):
+    """Find a user based on their Third Party ID.
+
+    Finds a user based on their Third Party ID (3PID) where medium is the kind
+    of Third Party ID that is used such as 'email' or 'msidn'.
+    """
+    helper.output(helper.api.user_3pid_search(medium, address))
